function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var isDebug = false; // 调试模式

function setDebug() {
  var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  isDebug = value;
}

var minLen = 5; // 文本分片最小长度

var stepLen = 10; // 文本分片长度

var reverseLen = 2; // 反向文本长度

var regCN = new RegExp("[\\u4e00-\\u9fa5\uFF0C\u3002\uFF1B\uFF01]{".concat(minLen, ",}"), 'g'); // 汉字&部分中文标点分片reg
// 压缩js时，'\u202e', '\u202c'会被移除

var sL = "\u202E";
var sR = "\u202C";

function getWrappedStr() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var start = arguments.length > 1 ? arguments[1] : undefined;
  var end = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : start;
  var prefix = typeof start !== 'undefined' ? start : isDebug ? "\u3010".concat(sL) : sL;
  var suffix = typeof end !== 'undefined' ? end : isDebug ? "".concat(sR, "\u3011") : sR;
  return "".concat(prefix).concat(str).concat(suffix);
}

function getWrappedReg() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var flag = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var reg = new RegExp(getWrappedStr(str), flag);
  return reg;
}

var defaultOpt = {
  debug: isDebug,
  value: '0',
  signature: {
    line: repeatStr('-', 30),
    value: '',
    toggle: false
  }
};
/**
 * @description 获取防折叠文本
 * @param {string} [text='']
 * @param {object} [options=defaultOpt]
 * @param {object} [appInfo={}]
 * @param {string} appInfo.platform 'ios' | 'android'
 * @param {string} appInfo.version '2825'
 * @return {string}
 */

function getUnfoldText() {
  var text = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultOpt;
  var appInfo = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  if (!isString(text)) return text;
  options = getObjParam(options);
  options = Object.keys(options).length > 0 ? options : defaultOpt; // 预备参数

  appInfo = getObjParam(appInfo);
  var _options = options,
      _options$debug = _options.debug,
      debug = _options$debug === void 0 ? false : _options$debug,
      _options$value = _options.value,
      mode = _options$value === void 0 ? '0' : _options$value,
      _options$signature = _options.signature;
  _options$signature = _options$signature === void 0 ? {} : _options$signature;
  var _options$signature$li = _options$signature.line,
      line = _options$signature$li === void 0 ? '' : _options$signature$li,
      _options$signature$va = _options$signature.value,
      value = _options$signature$va === void 0 ? '' : _options$signature$va,
      _options$signature$to = _options$signature.toggle,
      toggle = _options$signature$to === void 0 ? false : _options$signature$to;
  var result = text;
  setDebug(debug);

  switch (mode) {
    // 半自动模式
    case '2':
      {
        result = getUnfoldStr(text);
      }
      break;
    // 自动模式

    case '1':
      {
        result = getSign(text);
      }
      break;
  }

  return result;
}

function getObjParam(obj) {
  try {
    obj = !isObject(obj) ? JSON.parse(obj) : obj;
  } catch (error) {
    // android not support object param
    obj = {};
  }

  return obj;
}
/**
 * @description 获取防折叠字符串
 * @param {string} [text='']
 * @return {string}
 */


function getUnfoldStr() {
  var text = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  if (!isString(text)) return text; // 反防折叠

  text = getPlainText(text); // 防折叠

  text = text.replace(regCN, replacer);
  return text;

  function replacer(match) {
    var len = match.length;
    var times = len / stepLen | 0;
    var mod = len % stepLen;
    var lastStr = match.substring(times * stepLen);
    var result = '';

    try {
      console.log("match string: ".concat(match));
    } catch (error) {// android not support console
    }

    for (var i = 0; i < times; i++) {
      var start = i * stepLen;
      var end = start + stepLen;
      var str = match.substring(start, end);
      result += getDealStr(str, stepLen);
    }

    result += mod >= minLen ? getDealStr(lastStr, mod) : lastStr;
    return result;

    function getDealStr() {
      var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
      var len = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var reverseLen = getRangeNum(2, 4); // 反向文本长度

      var index = getRangeNum(0, len - reverseLen);
      return getReverseStr(str, index, index + reverseLen);
    }
  }
}

function getPlainText() {
  var text = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  if (!isString(text)) return text;
  var reg = getWrappedReg('(.*?)', 'g');
  return text.replace(reg, function (match, p) {
    return reverseString(p);
  });
}

function getAppPlainText() {
  var text = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultOpt;
  var appInfo = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var s = getPlainText(text); // 预备参数

  options = getObjParam(options);
  options = Object.keys(options).length > 0 ? options : defaultOpt;
  appInfo = getObjParam(appInfo);
  return s;
} // is string ?


function isString(str) {
  return typeof str === 'string';
} // is object ?


function isObject(obj) {
  return obj != null && _typeof(obj) === 'object';
}

function repeatStr() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var times = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  return new Array(times).join(str);
} // [min, max]


function getRangeNum(min, max) {
  return min + Math.random() * (max - min + 1) | 0;
} // [min, max)
// function getRangeNum(min, max) {
//     return (min + Math.random() * (max - min)) | 0;
// }
// reverse string


function reverseString(str) {
  return str.split('').reverse().join('');
} // get reverse str


function getReverseStr() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var start = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var end = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : start;
  var startStr = str.substring(0, start);
  var endStr = str.substring(end);
  var reverseStr = reverseString(str.substring(start, end));
  var centerStr = getWrappedStr(reverseStr);
  return "".concat(startStr).concat(centerStr).concat(endStr);
} // 获取随机unicode中文


function randomAccess(min, max) {
  return Math.floor(Math.random() * (min - max) + max);
} // 解码


function decodeUnicode(str) {
  // Unicode显示方式是\u4e00
  str = "\\u".concat(str);
  str = str.replace(/\\/g, '%'); // 转换中文

  str = unescape(str); // 将其他受影响的转换回原来

  str = str.replace(/%/g, '\\');
  return str;
}
/*
 *@param Number nameLength 要获取的名字长度
 const randomName = getRandomName(randomAccess(200, 300));
 */


function getRandomName(nameLength) {
  var name = '';

  for (var i = 0; i < nameLength; i++) {
    var unicodeNum = '';
    unicodeNum = randomAccess(0x4e00, 0x9fa5).toString(16);
    name += decodeUnicode(unicodeNum);
  }

  return name;
}

function getSign() {
  var text = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var len = text.length;
  if (len > 2000) return text;
  var strLine = getWrappedStr('你会读下面的几个字', repeatStr('-', 10));
  var before = repeatStr('\n', 3 + 2);
  var after = repeatStr('\n', 2);
  var newLine = getWrappedStr(strLine, before, after);
  var leftLen = 2000 - len - newLine.length;
  var useLen = leftLen < 300 ? leftLen : getRangeNum(200, 300);
  var randomStr = getRandomName(useLen);
  return "".concat(text).concat(newLine).concat(randomStr);
}